@@ -522,11 +522,16 @@ class CorrelationMatrix:
                 # minus 1 because still need core point from OPTICS
                 new_labels[: first_finite[0] - 1] = -1
             else:
-                # This means that the gradient never gets steep - so everything is one cluster
+                # This means that the gradient never gets steep within finite region - so everything is one cluster
                 new_labels = copy.deepcopy(initial_labels[optics_model.ordering_])
                 new_labels[: first_finite[0] - 1] = -1
                 new_labels[first_finite[0] :] = 0
 
+            # Check that all values originally marked as inf because cut by max_eps (all except first dataset) are labelled as noise
+
+            inf_mask = np.isinf(optics_model.reachability_[optics_model.ordering_][1:])
+            new_labels[1:][inf_mask] = -1
+
             # put back in dataset order rather than OPTICS order
 
             new_labels_dataset_order = np.empty_like(new_labels)
